import { LitElement } from 'lit';
export type UUIColorSliderOrientation = 'horizontal' | 'vertical';
export type UUIColorSliderType = 'hue' | 'opacity';
declare const UUIColorSliderElement_base: (new (...args: any[]) => import("@umbraco-ui/uui-base/lib/mixins").LabelMixinInterface) & typeof LitElement;
/**
 *  @element uui-color-slider
 *  @description A slider that is a part of uui-color-picker
 * @fires {UUIColorSliderEvent} change - Fires when the value of the slider changes.
 * @cssprop --uui-slider-height - The height of the slider.
 * @cssprop --uui-slider-handle-size - The size of the slider handle.
 * @cssprop --uui-slider-background-image - The background image of the slider.
 * @cssprop --uui-slider-background-size - The background size of the slider.
 * @cssprop --uui-slider-background-position - The background position of the slider.
 */
export declare class UUIColorSliderElement extends UUIColorSliderElement_base {
    /**
     * The type of the slider.
     * @type {UUIColorSliderType}
     * @attr
     * @default 'hue'
     */
    type: UUIColorSliderType;
    /**
     * The color value.
     * @type {string}
     * @attr
     * @default ''
     */
    color: string;
    /**
     * This is a minimum value of the slider.
     * @type {number}
     * @attr
     * @default 0
     */
    min: number;
    /**
     * This is a maximum value of the slider.
     * @type {number}
     * @attr
     * @default 100
     */
    max: number;
    /**
     * The minimum increment value allowed by the slider.
     * @type {number}
     * @attr
     **/
    precision: number;
    /**
     * Draws the slider in a vertical orientation.
     * @type {boolean}
     * @attr
     * @default false
     **/
    vertical: boolean;
    /**
     * The current value of the slider.
     * @type {number}
     * @attr
     * @default 0
     */
    value: number;
    /**
     * Disables the color slider.
     * @type {boolean}
     * @attr
     * @default false
     **/
    disabled: boolean;
    private container;
    private handle;
    willUpdate(changedProperties: Map<string, any>): void;
    firstUpdated(): void;
    handleDrag(event: PointerEvent): void;
    handleClick(event: MouseEvent): void;
    handleKeyDown(event: KeyboardEvent): void;
    getValueFromMousePosition(event: MouseEvent): number;
    getValueFromTouchPosition(event: TouchEvent): number;
    getValueFromXCoordinate(coordinate: number): number;
    getValueFromYCoordinate(coordinate: number): number;
    roundToPrecision(numberToRound: number): number;
    syncValues(): void;
    get ccsPropCurrentValue(): number;
    render(): import("lit-html").TemplateResult<1>;
    static styles: import("lit").CSSResult[];
}
declare global {
    interface HTMLElementTagNameMap {
        'uui-color-slider': UUIColorSliderElement;
    }
}
export {};
